@@ -33,10 +33,12 @@
 #include <gconf/gconf-client.h>
 #include <devkit-power-gobject/devicekit-power.h>
 
+#include "egg-debug.h"
+#include "egg-console-kit.h"
+
 #include "gpm-tray-icon.h"
 #include "gpm-common.h"
 #include "gpm-prefs-core.h"
-#include "egg-debug.h"
 #include "gpm-stock-icons.h"
 #include "gpm-prefs-server.h"
 
@@ -58,6 +60,7 @@ struct GpmPrefsPrivate
 	gboolean		 can_hibernate;
 	guint			 idle_delay;
 	GConfClient		*conf;
+	EggConsoleKit		*console;
 };
 
 enum {
@@ -331,7 +334,6 @@ gpm_prefs_setup_action_combo (GpmPrefs *prefs, const gchar *widget_name,
 {
 	gchar *value_txt;
 	gint i;
-	gint n_added = 0;
 	gboolean is_writable;
 	GtkWidget *widget;
 	GpmActionPolicy policy;
@@ -360,7 +362,6 @@ gpm_prefs_setup_action_combo (GpmPrefs *prefs, const gchar *widget_name,
 		} else if (policy == GPM_ACTION_POLICY_SHUTDOWN && prefs->priv->can_shutdown) {
 			gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Shutdown"));
 			g_ptr_array_add (array, GINT_TO_POINTER (policy));
-			n_added++;
 		} else if (policy == GPM_ACTION_POLICY_SUSPEND && !prefs->priv->can_suspend) {
 			egg_debug ("Cannot add option, as cannot suspend.");
 		} else if (policy == GPM_ACTION_POLICY_HIBERNATE && !prefs->priv->can_hibernate) {
@@ -368,25 +369,20 @@ gpm_prefs_setup_action_combo (GpmPrefs *prefs, const gchar *widget_name,
 		} else if (policy == GPM_ACTION_POLICY_SUSPEND && prefs->priv->can_suspend) {
 			gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Suspend"));
 			g_ptr_array_add (array, GINT_TO_POINTER (policy));
-			n_added++;
 		} else if (policy == GPM_ACTION_POLICY_HIBERNATE && prefs->priv->can_hibernate) {
 			gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Hibernate"));
 			g_ptr_array_add (array, GINT_TO_POINTER (policy));
-			n_added++;
 		} else if (policy == GPM_ACTION_POLICY_BLANK) {
 			gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Blank screen"));
 			g_ptr_array_add (array, GINT_TO_POINTER (policy));
-			n_added++;
 		} else if (policy == GPM_ACTION_POLICY_INTERACTIVE) {
 			gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Ask me"));
 			g_ptr_array_add (array, GINT_TO_POINTER (policy));
-			n_added++;
 		} else if (policy == GPM_ACTION_POLICY_NOTHING) {
 			/* we only add do nothing in the GUI if the user has explicitly specified this in GConf */
 			if (value == GPM_ACTION_POLICY_NOTHING) {
 				gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Do nothing"));
 				g_ptr_array_add (array, GINT_TO_POINTER (policy));
-				n_added++;
 			}
 		} else {
 			egg_warning ("Unknown action read from conf: %i", policy);
@@ -394,8 +390,11 @@ gpm_prefs_setup_action_combo (GpmPrefs *prefs, const gchar *widget_name,
 	}
 
 	/* save as array _only_ the actions we could add */
-	actions_added = (GpmActionPolicy *) g_ptr_array_free (array, FALSE);
-	actions_added[n_added] = -1;
+	actions_added = g_new0 (GpmActionPolicy, array->len+1);
+	for (i=0; i<array->len; i++)
+		actions_added[i] = GPOINTER_TO_INT (g_ptr_array_index (array, i));
+	actions_added[i] = -1;
+
 	g_object_set_data_full (G_OBJECT (widget), "actions", (gpointer) actions_added, (GDestroyNotify) gpm_prefs_actions_destroy_cb);
 
 	/* set what we have in GConf */
@@ -406,6 +405,7 @@ gpm_prefs_setup_action_combo (GpmPrefs *prefs, const gchar *widget_name,
 			 gtk_combo_box_set_active (GTK_COMBO_BOX (widget), i);
 	}
 
+	g_ptr_array_free (array, TRUE);
 	g_free (value_txt);
 }
 
@@ -932,6 +932,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 	prefs->priv = GPM_PREFS_GET_PRIVATE (prefs);
 
 	prefs->priv->client = dkp_client_new ();
+	prefs->priv->console = egg_console_kit_new ();
 	prefs->priv->conf = gconf_client_get_default ();
 	/* watch gnome-power-manager keys */
 	gconf_client_add_dir (prefs->priv->conf, GPM_CONF_DIR,
@@ -944,13 +945,18 @@ gpm_prefs_init (GpmPrefs *prefs)
 	prefs->priv->idle_delay = gconf_client_get_int (prefs->priv->conf, GPM_CONF_IDLE_DELAY, NULL);
 
 	caps = gpm_dbus_get_caps (prefs);
+	egg_debug ("caps=%i", caps);
+
+	/* get properties from gnome-power-manager */
 	prefs->priv->has_batteries = ((caps & GPM_PREFS_SERVER_BATTERY) > 0);
 	prefs->priv->has_ups = ((caps & GPM_PREFS_SERVER_UPS) > 0);
 	prefs->priv->has_lcd = ((caps & GPM_PREFS_SERVER_BACKLIGHT) > 0);
 	prefs->priv->has_button_lid = ((caps & GPM_PREFS_SERVER_LID) > 0);
 	prefs->priv->has_button_suspend = TRUE;
+
+	/* are we allowed to shutdown? */
 	prefs->priv->can_shutdown = TRUE;
-	egg_debug ("caps=%i", caps);
+	egg_console_kit_can_stop (prefs->priv->console, &prefs->priv->can_shutdown, NULL);
 
 	/* get values from DkpClient */
 	g_object_get (prefs->priv->client,
@@ -1016,6 +1022,7 @@ gpm_prefs_finalize (GObject *object)
 
 	g_object_unref (prefs->priv->conf);
 	g_object_unref (prefs->priv->client);
+	g_object_unref (prefs->priv->console);
 
 	G_OBJECT_CLASS (gpm_prefs_parent_class)->finalize (object);
 }
